PELE_Platform
##################

|MIT license| |GitHub release| |PyPI release| |Conda release| |Code Coverage|

Pele platform is a python module to automatically launch PELE, AdaptivePELE, MSMPELE and FragPELE. It is built as a python layer on top of all PELE functionalities that can be used as a backend for a potential future GUI.

PELE_Platform Functionalities
======================================

Automatically prepare and launch PELE & FragPELE input

Install
=====================

https://nostrumbiodiscovery.github.io/pele_platform/installation/index.html


Get Started
===============

https://nostrumbiodiscovery.github.io/pele_platform/tutorial/index.html

Documentation of the input parameters
=======================================

https://nostrumbiodiscovery.github.io/pele_platform/documentation/index.html

What's new
============

https://nostrumbiodiscovery.github.io/pele_platform/changelog/index.html


.. |MIT license| image:: https://img.shields.io/badge/License-MIT-blue.svg
   :target: https://lbesson.mit-license.org/


.. |GitHub release| image:: https://img.shields.io/github/release/NostrumBioDiscovery/pele_platform.svg
    :target: https://github.com/NostrumBioDiscovery/pele_platform/releases/

.. |PyPI release| image:: https://img.shields.io/pypi/v/pele_platform.svg
    :target: https://pypi.org/project/pele_platform/

.. |Conda release| image:: https://anaconda.org/nostrumbiodiscovery/pele_platform/badges/version.svg 
    :target: https://anaconda.org/nostrumbiodiscovery/pele_platform

.. |Code Coverage| image:: https://codecov.io/gh/NostrumBioDiscovery/pele_platform/branch/devel/graph/badge.svg
    :target: https://codecov.io/gh/NostrumBioDiscovery/pele_platform/branch/devel/
